@@ -43,7 +43,7 @@ BorderImages::BorderImages(const int border_image_ids[],
     return;
 
   border_painter = Painter::CreateImageGridPainter(border_image_ids);
-  ResourceBundle& rb = ResourceBundle::GetSharedInstance();
+  ui::ResourceBundle& rb = ui::ResourceBundle::GetSharedInstance();
   border_thickness = rb.GetImageSkiaNamed(border_image_ids[0])->width();
 
   if (arrow_image_ids[0] != 0) {
@@ -77,7 +77,7 @@ const int kLargeShadowVerticalOffset = 2;
 const int kLargeShadowBlur = 6;
 const SkColor kLargeShadowColor = SkColorSetA(SK_ColorBLACK, 0x1A);
 
-bool UseMd() {
+bool UseMaterialDesign() {
   return ui::MaterialDesignController::IsSecondaryUiMaterial();
 }
 
@@ -187,13 +187,8 @@ BubbleBorder::BubbleBorder(Arrow arrow, Shadow shadow, SkColor color)
       images_(nullptr),
       background_color_(color),
       use_theme_background_color_(false) {
-#if defined(OS_MACOSX)
-  // On Mac, use the NO_ASSETS bubble border. WindowServer on Mac is able to
-  // generate drop shadows for dialogs, hence we don't use raster shadows.
-  shadow_ = NO_ASSETS;
-#endif  // OS_MACOSX
   DCHECK(shadow_ < SHADOW_COUNT);
-  if (UseMd()) {
+  if (UseMaterialDesign()) {
     // Harmony bubbles don't use arrows.
     alignment_ = ALIGN_EDGE_TO_ANCHOR_EDGE;
     arrow_paint_type_ = PAINT_NONE;
@@ -205,7 +200,7 @@ BubbleBorder::BubbleBorder(Arrow arrow, Shadow shadow, SkColor color)
 BubbleBorder::~BubbleBorder() {}
 
 void BubbleBorder::set_paint_arrow(ArrowPaintType value) {
-  if (UseMd())
+  if (UseMaterialDesign())
     return;
   arrow_paint_type_ = value;
 }
@@ -214,7 +209,7 @@ gfx::Rect BubbleBorder::GetBounds(const gfx::Rect& anchor_rect,
                                   const gfx::Size& contents_size) const {
   // In MD, there are no arrows, so positioning logic is significantly simpler.
   // TODO(estade): handle more anchor positions.
-  if (UseMd() &&
+  if (UseMaterialDesign() &&
       (arrow_ == TOP_RIGHT || arrow_ == TOP_LEFT || arrow_ == BOTTOM_CENTER ||
        arrow_ == LEFT_CENTER || arrow_ == RIGHT_CENTER)) {
     gfx::Rect contents_bounds(contents_size);
@@ -260,9 +255,10 @@ gfx::Rect BubbleBorder::GetBounds(const gfx::Rect& anchor_rect,
   const int stroke_width = shadow_ == NO_ASSETS ? 0 : kStroke;
   // |arrow_shift| is necessary to visually align the tip of the bubble arrow
   // with the anchor point. This shift is an inverse of the shadow thickness.
-  int arrow_shift = UseMd() ? 0
-                            : images_->arrow_interior_thickness + stroke_width -
-                                  images_->arrow_thickness;
+  int arrow_shift = UseMaterialDesign()
+                        ? 0
+                        : images_->arrow_interior_thickness + stroke_width -
+                              images_->arrow_thickness;
   // When arrow is painted transparently the visible border of the bubble needs
   // to be positioned at the same bounds as when the arrow is shown.
   if (arrow_paint_type_ == PAINT_TRANSPARENT)
@@ -304,17 +300,17 @@ gfx::Rect BubbleBorder::GetBounds(const gfx::Rect& anchor_rect,
 
 int BubbleBorder::GetBorderThickness() const {
   // TODO(estade): this shouldn't be called in MD.
-  return UseMd()
+  return UseMaterialDesign()
              ? 0
              : images_->border_thickness - images_->border_interior_thickness;
 }
 
 int BubbleBorder::GetBorderCornerRadius() const {
-  return UseMd() ? 3 : images_->corner_radius;
+  return UseMaterialDesign() ? 2 : images_->corner_radius;
 }
 
 int BubbleBorder::GetArrowOffset(const gfx::Size& border_size) const {
-  if (UseMd())
+  if (UseMaterialDesign())
     return 0;
 
   const int edge_length = is_arrow_on_horizontal(arrow_) ?
@@ -339,14 +335,14 @@ bool BubbleBorder::GetArrowPath(const gfx::Rect& view_bounds,
 
 void BubbleBorder::SetBorderInteriorThickness(int border_interior_thickness) {
   // TODO(estade): remove this function.
-  DCHECK(!UseMd());
+  DCHECK(!UseMaterialDesign());
   images_->border_interior_thickness = border_interior_thickness;
   if (!has_arrow(arrow_) || arrow_paint_type_ != PAINT_NORMAL)
     images_->border_thickness = border_interior_thickness;
 }
 
 void BubbleBorder::Paint(const views::View& view, gfx::Canvas* canvas) {
-  if (UseMd())
+  if (UseMaterialDesign())
     return PaintMd(view, canvas);
 
   gfx::Rect bounds(view.GetContentsBounds());
@@ -372,7 +368,7 @@ void BubbleBorder::Paint(const views::View& view, gfx::Canvas* canvas) {
 }
 
 gfx::Insets BubbleBorder::GetInsets() const {
-  if (UseMd()) {
+  if (UseMaterialDesign()) {
     if (shadow_ == NO_ASSETS)
       return gfx::Insets();
 
@@ -407,7 +403,7 @@ gfx::Size BubbleBorder::GetSizeForContentsSize(
   gfx::Size size(contents_size);
   const gfx::Insets insets = GetInsets();
   size.Enlarge(insets.width(), insets.height());
-  if (UseMd())
+  if (UseMaterialDesign())
     return size;
 
   // Ensure the bubble is large enough to not overlap border and arrow images.
@@ -480,7 +476,7 @@ gfx::Rect BubbleBorder::GetArrowRect(const gfx::Rect& bounds) const {
 
 void BubbleBorder::GetArrowPathFromArrowBounds(const gfx::Rect& arrow_bounds,
                                                SkPath* path) const {
-  DCHECK(!UseMd());
+  DCHECK(!UseMaterialDesign());
   const bool horizontal = is_arrow_on_horizontal(arrow_);
   const int thickness = images_->arrow_interior_thickness;
   float tip_x = horizontal ? arrow_bounds.CenterPoint().x() :
@@ -506,7 +502,7 @@ void BubbleBorder::GetArrowPathFromArrowBounds(const gfx::Rect& arrow_bounds,
 
 void BubbleBorder::DrawArrow(gfx::Canvas* canvas,
                              const gfx::Rect& arrow_bounds) const {
-  DCHECK(!UseMd());
+  DCHECK(!UseMaterialDesign());
   canvas->DrawImageInt(*GetArrowImage(), arrow_bounds.x(), arrow_bounds.y());
   SkPath path;
   GetArrowPathFromArrowBounds(arrow_bounds, &path);
